@@ -42,6 +42,7 @@ int main( int argc, char *argv[] )
     bool tracing_runtime_enabled = false;
     bool legacy_init = false;
     bool tracing_enabled = false;
+    bool npu_test = false;
     if( argparse( argc, argv, "-null", "--enable_null_driver" ) )
     {
         putenv_safe( const_cast<char *>( "ZE_ENABLE_NULL_DRIVER=1" ) );
@@ -69,13 +70,25 @@ int main( int argc, char *argv[] )
     {
         legacy_init = true;
     }
+    if( argparse( argc, argv, "-npu", "--enable_npu" ) )
+    {
+        npu_test = true;
+    }
 
     ze_result_t status;
-    const ze_device_type_t type = ZE_DEVICE_TYPE_GPU;
+    ze_device_type_t type = ZE_DEVICE_TYPE_GPU;
+    if (npu_test) {
+        std::cout << "NPU Test Enabled. Looking for NPU devices." << std::endl;
+        type = ZE_DEVICE_TYPE_VPU;
+    }
 
     ze_init_driver_type_desc_t driverTypeDesc = {};
     driverTypeDesc.stype = ZE_STRUCTURE_TYPE_INIT_DRIVER_TYPE_DESC;
-    driverTypeDesc.flags = ZE_INIT_DRIVER_TYPE_FLAG_GPU;
+    if (npu_test) {
+        driverTypeDesc.flags = ZE_INIT_DRIVER_TYPE_FLAG_NPU;
+    } else {
+        driverTypeDesc.flags = ZE_INIT_DRIVER_TYPE_FLAG_GPU;
+    }
     driverTypeDesc.pNext = nullptr;
 
     ze_driver_handle_t pDriver = nullptr;
@@ -98,16 +111,6 @@ int main( int argc, char *argv[] )
             }
         }
 
-        if (tracing_enabled) {
-            zel_tracer_desc_t tracer_desc = {ZEL_STRUCTURE_TYPE_TRACER_EXP_DESC, nullptr,
-                nullptr};
-            status = zelTracerCreate(&tracer_desc, &tracer);
-            if(status != ZE_RESULT_SUCCESS) {
-                std::cout << "zelTracerCreate Failed with return code: " << to_string(status) << std::endl;
-                exit(1);
-            }
-        }
-
         if (legacy_init) {
             status = zeDriverGet(&driverCount, nullptr);
             if(status != ZE_RESULT_SUCCESS) {
@@ -154,6 +157,15 @@ int main( int argc, char *argv[] )
             std::cout << "No valid device found for Driver #" << driver_idx << std::endl;
             continue;
         }
+        if (tracing_enabled) {
+            zel_tracer_desc_t tracer_desc = {ZEL_STRUCTURE_TYPE_TRACER_EXP_DESC, nullptr,
+                nullptr};
+            status = zelTracerCreate(&tracer_desc, &tracer);
+            if(status != ZE_RESULT_SUCCESS) {
+                std::cout << "zelTracerCreate Failed with return code: " << to_string(status) << std::endl;
+                exit(1);
+            }
+        }
         pDriver = drivers[driver_idx];
         pDevice = devices_per_driver[driver_idx];
         std::cout << "Executing on Driver #" << driver_idx << ", Device #" << 0 << std::endl;
